@@ -5,8 +5,8 @@ from sweetspot.https.http_client import HttpClient
 class Configuration(object): 
 
 	environments = {
-		'development': 'http://app:5000/api',
-		'production': 'http://sweetspot.so'
+		'development': 'http://merchant-api:5000/api',
+		'production': 'https://sweetspot.so'
 	}
 
 	def __init__(self, csrf_access_token=None, 
